#
# spec file for package python-gsw
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Note: this package is python3-only. There is a python2-compatible
# version in the python2-gsw package.
# Tests are not included in the source tarball
%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-gsw
Version:        3.3.1
Release:        bp155.2.12
Summary:        Gibbs Seawater Oceanographic Package of TEOS-10
# Note: Python code is MIT licensed
# C-code IS BSD-3-Clause licensed (see src/c_gsw/LICENSE)
# MATLAB function names and documentation are BSD-3-Clause licensed (see http://teos-10.org/pubs/gsw/html/gsw_licence.html)
License:        MIT AND BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/TEOS-10/GSW-python
# gh#TEOS-10/GSW-Python#39
Source0:        https://github.com/TEOS-10/GSW-Python/archive/v%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.5}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
Requires:       python-numpy
# SECTION tests
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Python implementation of the Thermodynamic Equation of
Seawater 2010 (TEOS-10).

%prep
%setup -q -n GSW-Python-%{version}

%build
CFLAGS="%{optflags}"
%ifarch i586 armv7l
CFLAGS="$CFLAGS -ffloat-store"
%endif
export CFLAGS
%python_build

%install
%python_install
%{python_expand %fdupes %{buildroot}%{$python_sitearch}}

# gh#TEOS-10/GSW-Python#40
%check
%{python_expand export PYTHONPATH=%{buildroot}%{python_sitearch}
%ifarch aarch64
py.test-%{$python_bin_suffix} -v -k 'not test_check_function[cfcf72]'
%else
py.test-%{$python_bin_suffix} -v
%endif
}

%files %{python_files}
%doc README.rst
%license LICENSE src/c_gsw/LICENSE
%{python_sitearch}/*

%changelog
* Thu Aug 20 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on aarch64 by ignoring test_check_function[cfcf72]
  See: gh#TEOS-10/GSW-Python#40
* Wed Apr 24 2019 pgajdos@suse.com
- version update to 3.3.1
  * Add optional args to p_from_z and z_from_p (#49).
- github tar ball forever (#39)
* Wed Feb 20 2019 Matej Cepl <mcepl@suse.com>
- Update to 3.3.0:
  * Adds functions SP_salinometer, O2sol, and O2sol_SP_pt by
    updating the C source.
  * Fixes a bug in handling of p_ref in geostrophy.
  * Fixes a bug in distance when the pressure argument is
    omitted.
- Actually gh#TEOS-10/GSW-Python#40 can be worked around by
  adding -ffloat-store to CFLAGS. Which I do now for i586 and
  armv7l platforms.
* Thu Jul 26 2018 mcepl@suse.com
- Switch off test_check_function[cfcf71], which fails on 32bit archs
  (gh#TEOS-10/GSW-Python#40).
* Thu Jul 26 2018 mcepl@suse.com
- Clean SPEC
- Remove gsw_licence.html (license is inside the distribution tarball)
- Add tests.tar.gz with tests from the upstream git repository and
  enable tests
* Sat Jun  2 2018 sebix+novell.com@sebix.at
- update to version 3.2.1, no changelog available, listing
  relevant git commits:
  * Fix bug in pchip_interp utility function. (#27)
  A smoke test has been added for this function.
  The function is an additional wrapper around the wrapped ufunc,
  the core of which is in C, and it is not used internally.
  * Make the code c/c++ compatible; eliminate source duplication. (#28)
  * Cleanup: warnings and last reference to src2. (#32)
  * This is a minor cleanup of the code generators and associated C.
* Fri Mar  2 2018 sebix+novell.com@sebix.at
- update to version 3.2.0
  * no changelog available
- remove check boundary condition
- use %%license macro
- convert to singlespec and deactivate python2
- use fdupes
* Wed Jul 12 2017 toddrme2178@gmail.com
- Initial version
